==> org-lsst-ccs-subsystem-rafts-buses-2.1.4-sources.jar: org/lsst/ccs/subsystem/rafts/fpga/main/Compiler.java <==
package org.lsst.ccs.subsystem.rafts.fpga.main;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.Date;
import java.util.List;
import org.kohsuke.args4j.Argument;
import org.kohsuke.args4j.CmdLineException;
import org.kohsuke.args4j.CmdLineParser;
import org.kohsuke.args4j.Option;
import org.lsst.ccs.subsystem.rafts.fpga.compiler.FPGA2Model;
import org.lsst.ccs.subsystem.rafts.fpga.compiler.FPGA2ModelBuilder;

/**
 * A main routine to output a compiled sequencer file as a .compiled file.
 * @author tonyj
 */
public class Compiler {

    @Argument(required = true, usage = "Input (.seq) File")
    private File file;

    @Argument(required = false, index = 1, usage = "Output (.compiled) file")
    private File outputFile;
   
    @Option(name="--noheader", usage = "Suppress output file header")
    private boolean noHeader;

    public static void main(String[] args) throws FileNotFoundException, IOException {
        new Compiler().doMain(args);
    }

    private void doMain(String[] args) throws FileNotFoundException, IOException {
        CmdLineParser parser = new CmdLineParser(this);
        try {
            // parse the arguments.
            parser.parseArgument(args);
            compile();

        } catch (CmdLineException e) {

            System.err.println(e.getMessage());
            System.err.println("java Compiler [options...] arguments...");
            // print the list of available options
            parser.printUsage(System.err);
            System.err.println();
        }
    }

    private void compile() throws FileNotFoundException, IOException {

        String fileName = file.getName();
        if (outputFile == null) {
            String outputFileName;
            if (fileName.endsWith(".seq")) {
                outputFileName = fileName.replace(".seq", ".compiled");
            } else {
                outputFileName = fileName.concat(".compiled");
            }
            outputFile = new File(outputFileName);
        }

        try (InputStream input = new FileInputStream(file)) {
            FPGA2ModelBuilder builder = new FPGA2ModelBuilder();
            FPGA2Model compiled = builder.compileFile(input);
            List<FPGA2Model.AddressAndValue> data = compiled.getMemoryMap();
            try (PrintWriter pw = new PrintWriter(outputFile)) {
                if (!noHeader) {
                    printHeader(pw, fileName, compiled);
                }
                data.forEach((datum) -> {
                    pw.printf("%08x: %08x\n", datum.getAddress(), datum.getValue());
                });
            }
        }
    }

    private void printHeader(final PrintWriter pw, String fileName, FPGA2Model compiled) {
        pw.printf("# Compilation of %s at %s\n", fileName, new Date());
        pw.printf("# Checksum: %08x\n", compiled.computeCheckSum());
        
        pw.println("#---");
        pw.println("#--- POINTERS");
        pw.println("#---");
        
        compiled.getPointers().stream().forEach((i) -> {
            pw.printf("# %-20s  %03x  %s\n", i.getKind(), i.getOffset(), i.getName());
        });
        
        pw.println("#---");
        pw.println("#--- MAINS");
        pw.println("#---");
        
        compiled.getMainAddresses().entrySet().stream().forEach((i) -> {
            pw.printf("# %-20s  %08x \n", i.getKey(), i.getValue());
        });
    }
}

==> org-lsst-ccs-subsystem-rafts-buses-3.0.14-sources.jar: org/lsst/ccs/subsystem/rafts/fpga/main/Compiler.java <==
package org.lsst.ccs.subsystem.rafts.fpga.main;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import org.kohsuke.args4j.Argument;
import org.kohsuke.args4j.CmdLineException;
import org.kohsuke.args4j.CmdLineParser;
import org.kohsuke.args4j.Option;
import org.lsst.ccs.subsystem.rafts.fpga.compiler.FPGA2Model;
import org.lsst.ccs.subsystem.rafts.fpga.compiler.FPGA2ModelBuilder;

/**
 * A main routine to output a compiled sequencer file as a .compiled file.
 * @author tonyj
 */
public class Compiler {

    @Argument(required = true, usage = "Input (.seq) File")
    private File file;

    @Argument(required = false, index = 1, usage = "Output (.compiled) file")
    private File outputFile;
   
    @Option(name="--noheader", usage = "Suppress output file header")
    private boolean noHeader;

    @Option(name = "-c", aliases="--clockperiod", usage = "Override the clockperiod specified in the .seq file", handler = BigDecimalOptionHandler.class)
    @SuppressWarnings("FieldMayBeFinal")
    private BigDecimal clockPeriodOverride = null;
    
    public static void main(String[] args) throws FileNotFoundException, IOException {
        new Compiler().doMain(args);
    }

    private void doMain(String[] args) throws FileNotFoundException, IOException {
        CmdLineParser parser = new CmdLineParser(this);
        try {
            // parse the arguments.
            parser.parseArgument(args);
            compile();

        } catch (CmdLineException e) {

            System.err.println(e.getMessage());
            System.err.println("java Compiler [options...] arguments...");
            // print the list of available options
            parser.printUsage(System.err);
            System.err.println();
        }
    }

    private void compile() throws FileNotFoundException, IOException {

        String fileName = file.getName();
        if (outputFile == null) {
            String outputFileName;
            if (fileName.endsWith(".seq")) {
                outputFileName = fileName.replace(".seq", ".compiled");
            } else {
                outputFileName = fileName.concat(".compiled");
            }
            outputFile = new File(outputFileName);
        }

        try (InputStream input = new FileInputStream(file)) {
            FPGA2ModelBuilder builder = new FPGA2ModelBuilder();
            FPGA2Model compiled = builder.compileFile(input, clockPeriodOverride);
            List<FPGA2Model.AddressAndValue> data = compiled.getMemoryMap();
            try (PrintWriter pw = new PrintWriter(outputFile)) {
                if (!noHeader) {
                    printHeader(pw, fileName, compiled);
                }
                data.forEach((datum) -> {
                    pw.printf("%08x: %08x\n", datum.getAddress(), datum.getValue());
                });
            }
        }
    }

    private void printHeader(final PrintWriter pw, String fileName, FPGA2Model compiled) {
        pw.printf("# Compilation of %s at %s\n", fileName, new Date());
        pw.printf("# Checksum: %08x\n", compiled.computeCheckSum());
        
        pw.println("#---");
        pw.println("#--- POINTERS");
        pw.println("#---");
        
        compiled.getPointers().stream().forEach((i) -> {
            pw.printf("# %-20s  %03x  %s\n", i.getKind(), i.getOffset(), i.getName());
        });
        
        pw.println("#---");
        pw.println("#--- MAINS");
        pw.println("#---");
        
        compiled.getMainAddresses().entrySet().stream().forEach((i) -> {
            pw.printf("# %-20s  %08x \n", i.getKey(), i.getValue());
        });
    }
}
